@@ -1,4 +1,4 @@
-__version__ = '0.2.16'
+__version__ = '0.2.17'
 
 DB_VERSION = 1
 
@@ -8,7 +8,7 @@ DEFAULT_TIMEOUT = 5
 
 DEFAULT_CACHE_SIZE = 1000
 
-SOCKET_BUF = 8192
+SOCKET_BUF = 1024
 
 FMTS = ['json', 'yaml', 'msgpack', 'cbor', 'pickle']
 
@@ -253,7 +253,7 @@ class YEDB():
             raise ChecksumError(data['error']['message'])
         elif error_code == -32003:
             raise SchemaValidationError(data['error']['message'])
-        if error_code == -32681:
+        elif error_code == -32005:
             raise FieldNotFound(data['error']['message'])
         else:
             raise RuntimeError(data['error']['message'])
